@@ -6,11 +6,16 @@
 # license:   perl
 
 package Module::Install::Stardoc;
+use 5.008003;
 use strict;
 use warnings;
-use 5.008003;
 
-use Module::Install::Base; use vars qw(@ISA); BEGIN { @ISA = 'Module::Install::Base' }
+use Module::Install::Base;
+use vars qw'@ISA $VERSION';
+BEGIN {
+    @ISA = 'Module::Install::Base';
+    $VERSION = '0.13';
+}
 
 use File::Find;
 
